==> tine20-exampleapplication_2016.11.24.tar.bz2: ExampleApplication/js/ExampleApplication-lang-cs-debug.js <==
/********************** tine translations of ExampleApplication**********************/ 
Locale.Gettext.prototype._msgs['./LC_MESSAGES/ExampleApplication'] = new Locale.Gettext.PO(({
""
: "Project-Id-Version: Tine 2.0 - ExampleApplication\nReport-Msgid-Bugs-To: \nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2012-03-02 12:56+0000\nLast-Translator: Michal Sladek <Unknown>\nLanguage-Team: Tine 2.0 Translators\nLanguage: \nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;\nX-Launchpad-Export-Date: 2012-03-03 05:53+0000\nX-Generator: Launchpad (build 14886)\nX-Poedit-Language: Czech\nX-Poedit-SourceCharset: utf-8\n"

, "Status Available"
: ""

, "Possible status. Please note that additional status might impact other ExampleApplication systems on export or syncronisation."
: ""

, "%s's personal example records"
: "Osobní ukázkové záznamy uživatele %s"

, "Example Application test"
: ""

, "ExampleRecord"
: "Ukázkový záznam"

, "Name"
: "Název"

, "Status"
: "Stav"

, "Title"
: "Název"

, "Budget"
: "Rozpočet"

, "Show closed"
: "Zobrazit uzavřené"

, "example record, example records"
: [
  "ukázkový záznam"
 ,"ukázkové záznamy"
 ,"ukázkových záznamů"

]
, "example record list, example record lists"
: [
  "seznam ukázkových záznamů"
 ,"seznamy ukázkových záznamů"
 ,"seznamů ukázkových záznamů"

]
, "Quick Search"
: "Rychlé hledání"

, "Last modified"
: ""

, "Last modifier"
: ""

, "Creation Time"
: ""

, "Creator"
: ""

, "Completed"
: ""

, "Cancelled"
: ""

, "In process"
: ""

, "ExampleApplication"
: "Ukázková aplikace"

, "Example Application"
: "Ukázková aplikace"

, "ExampleRecords"
: "Ukázkové záznamy"

, "All ExampleRecords"
: "Všechny ukázkové záznamy"

, "Unit"
: "Jednotka"

, "Unit Price"
: "Jednotková cena"

, "Timesheets are billable"
: "Pracovní výkazy lze účtovat"

, "closed"
: "uzavřený"

, "open"
: "otevřený"

, "Billed"
: "Účtovaný"

, "not yet billed"
: "zatím neúčtovaný"

, "to bill"
: "k účtování"

, "billed"
: "účtovaný"

, "Description"
: "Popis"

, "example record"
: "ukázkový záznam"

, "example record list"
: "seznam ukázkových záznamů"

}));

==> tine20-exampleapplication_2017.08.11.tar.bz2: ExampleApplication/js/ExampleApplication-lang-cs-debug.js <==
/********************** tine translations of ExampleApplication**********************/ 
Locale.Gettext.prototype._msgs['./LC_MESSAGES/ExampleApplication'] = new Locale.Gettext.PO(({
""
: "Project-Id-Version: Tine 2.0 - ExampleApplication\nReport-Msgid-Bugs-To: \nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2012-03-02 12:56+0000\nLast-Translator: Michal Sladek <Unknown>\nLanguage-Team: Tine 2.0 Translators\nLanguage: \nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;\nX-Launchpad-Export-Date: 2012-03-03 05:53+0000\nX-Generator: Launchpad (build 14886)\nX-Poedit-Language: Czech\nX-Poedit-SourceCharset: utf-8\n"

, "ExampleRecord"
: "Ukázkový záznam"

, "Name"
: "Název"

, "Status"
: "Stav"

, "Reason"
: ""

, "Total Example Records"
: ""

, "New Example"
: ""

, "Status Available"
: ""

, "Possible status. Please note that additional status might impact other ExampleApplication systems on export or syncronisation."
: ""

, "Completed"
: ""

, "Cancelled"
: ""

, "In process"
: ""

, "Reasons Available"
: ""

, "Possible status reasons."
: ""

, "Change"
: ""

, "Documentation"
: ""

, "Requirement Changed"
: ""

, "Not Possible"
: ""

, "Implementation"
: ""

, "Review"
: ""

, "Integration"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Sales Application."
: ""

, "Invoices Module"
: ""

, "Example String"
: ""

, "Just an example string for test purpose"
: ""

, "ExampleApplication"
: "Ukázková aplikace"

, "example record, example records"
: [
  "ukázkový záznam"
 ,"ukázkové záznamy"
 ,"ukázkových záznamů"

]
, "example records"
: ""

, "example record list"
: "seznam ukázkových záznamů"

, "example record lists"
: ""

, "Number"
: ""

, "Default Example Record Container"
: ""

, "The default container for new records"
: ""



















, "example record"
: "ukázkový záznam"

}));
